/*
 * This material is distributed under the GNU General Public License
 * Version 2. You may review the terms of this license at
 * http://www.gnu.org/licenses/gpl-2.0.html
 *
 * Copyright (c) 1997-2014, The R Core Team
 * Copyright (c) 2003, The R Foundation
 * Copyright (c) 2017, Oracle and/or its affiliates
 *
 * All rights reserved.
 */
package com.oracle.truffle.r.library.fastrGrid;

import java.util.HashMap;

final class ColorNames {
    private static HashMap<String, String> synonymToHexName;

    public static String findByName(String synonym) {
        if (synonymToHexName == null) {
            initialize();
        }
        return synonymToHexName.get(synonym);
    }

    private static void initialize() {
        synonymToHexName = new HashMap<>(700);
        synonymToHexName.put("white", "#FFFFFF");
        synonymToHexName.put("aliceblue", "#F0F8FF");
        synonymToHexName.put("antiquewhite", "#FAEBD7");
        synonymToHexName.put("antiquewhite1", "#FFEFDB");
        synonymToHexName.put("antiquewhite2", "#EEDFCC");
        synonymToHexName.put("antiquewhite3", "#CDC0B0");
        synonymToHexName.put("antiquewhite4", "#8B8378");
        synonymToHexName.put("aquamarine", "#7FFFD4");
        synonymToHexName.put("aquamarine1", "#7FFFD4");
        synonymToHexName.put("aquamarine2", "#76EEC6");
        synonymToHexName.put("aquamarine3", "#66CDAA");
        synonymToHexName.put("aquamarine4", "#458B74");
        synonymToHexName.put("azure", "#F0FFFF");
        synonymToHexName.put("azure1", "#F0FFFF");
        synonymToHexName.put("azure2", "#E0EEEE");
        synonymToHexName.put("azure3", "#C1CDCD");
        synonymToHexName.put("azure4", "#838B8B");
        synonymToHexName.put("beige", "#F5F5DC");
        synonymToHexName.put("bisque", "#FFE4C4");
        synonymToHexName.put("bisque1", "#FFE4C4");
        synonymToHexName.put("bisque2", "#EED5B7");
        synonymToHexName.put("bisque3", "#CDB79E");
        synonymToHexName.put("bisque4", "#8B7D6B");
        synonymToHexName.put("black", "#000000");
        synonymToHexName.put("blanchedalmond", "#FFEBCD");
        synonymToHexName.put("blue", "#0000FF");
        synonymToHexName.put("blue1", "#0000FF");
        synonymToHexName.put("blue2", "#0000EE");
        synonymToHexName.put("blue3", "#0000CD");
        synonymToHexName.put("blue4", "#00008B");
        synonymToHexName.put("blueviolet", "#8A2BE2");
        synonymToHexName.put("brown", "#A52A2A");
        synonymToHexName.put("brown1", "#FF4040");
        synonymToHexName.put("brown2", "#EE3B3B");
        synonymToHexName.put("brown3", "#CD3333");
        synonymToHexName.put("brown4", "#8B2323");
        synonymToHexName.put("burlywood", "#DEB887");
        synonymToHexName.put("burlywood1", "#FFD39B");
        synonymToHexName.put("burlywood2", "#EEC591");
        synonymToHexName.put("burlywood3", "#CDAA7D");
        synonymToHexName.put("burlywood4", "#8B7355");
        synonymToHexName.put("cadetblue", "#5F9EA0");
        synonymToHexName.put("cadetblue1", "#98F5FF");
        synonymToHexName.put("cadetblue2", "#8EE5EE");
        synonymToHexName.put("cadetblue3", "#7AC5CD");
        synonymToHexName.put("cadetblue4", "#53868B");
        synonymToHexName.put("chartreuse", "#7FFF00");
        synonymToHexName.put("chartreuse1", "#7FFF00");
        synonymToHexName.put("chartreuse2", "#76EE00");
        synonymToHexName.put("chartreuse3", "#66CD00");
        synonymToHexName.put("chartreuse4", "#458B00");
        synonymToHexName.put("chocolate", "#D2691E");
        synonymToHexName.put("chocolate1", "#FF7F24");
        synonymToHexName.put("chocolate2", "#EE7621");
        synonymToHexName.put("chocolate3", "#CD661D");
        synonymToHexName.put("chocolate4", "#8B4513");
        synonymToHexName.put("coral", "#FF7F50");
        synonymToHexName.put("coral1", "#FF7256");
        synonymToHexName.put("coral2", "#EE6A50");
        synonymToHexName.put("coral3", "#CD5B45");
        synonymToHexName.put("coral4", "#8B3E2F");
        synonymToHexName.put("cornflowerblue", "#6495ED");
        synonymToHexName.put("cornsilk", "#FFF8DC");
        synonymToHexName.put("cornsilk1", "#FFF8DC");
        synonymToHexName.put("cornsilk2", "#EEE8CD");
        synonymToHexName.put("cornsilk3", "#CDC8B1");
        synonymToHexName.put("cornsilk4", "#8B8878");
        synonymToHexName.put("cyan", "#00FFFF");
        synonymToHexName.put("cyan1", "#00FFFF");
        synonymToHexName.put("cyan2", "#00EEEE");
        synonymToHexName.put("cyan3", "#00CDCD");
        synonymToHexName.put("cyan4", "#008B8B");
        synonymToHexName.put("darkblue", "#00008B");
        synonymToHexName.put("darkcyan", "#008B8B");
        synonymToHexName.put("darkgoldenrod", "#B8860B");
        synonymToHexName.put("darkgoldenrod1", "#FFB90F");
        synonymToHexName.put("darkgoldenrod2", "#EEAD0E");
        synonymToHexName.put("darkgoldenrod3", "#CD950C");
        synonymToHexName.put("darkgoldenrod4", "#8B6508");
        synonymToHexName.put("darkgray", "#A9A9A9");
        synonymToHexName.put("darkgreen", "#006400");
        synonymToHexName.put("darkgrey", "#A9A9A9");
        synonymToHexName.put("darkkhaki", "#BDB76B");
        synonymToHexName.put("darkmagenta", "#8B008B");
        synonymToHexName.put("darkolivegreen", "#556B2F");
        synonymToHexName.put("darkolivegreen1", "#CAFF70");
        synonymToHexName.put("darkolivegreen2", "#BCEE68");
        synonymToHexName.put("darkolivegreen3", "#A2CD5A");
        synonymToHexName.put("darkolivegreen4", "#6E8B3D");
        synonymToHexName.put("darkorange", "#FF8C00");
        synonymToHexName.put("darkorange1", "#FF7F00");
        synonymToHexName.put("darkorange2", "#EE7600");
        synonymToHexName.put("darkorange3", "#CD6600");
        synonymToHexName.put("darkorange4", "#8B4500");
        synonymToHexName.put("darkorchid", "#9932CC");
        synonymToHexName.put("darkorchid1", "#BF3EFF");
        synonymToHexName.put("darkorchid2", "#B23AEE");
        synonymToHexName.put("darkorchid3", "#9A32CD");
        synonymToHexName.put("darkorchid4", "#68228B");
        synonymToHexName.put("darkred", "#8B0000");
        synonymToHexName.put("darksalmon", "#E9967A");
        synonymToHexName.put("darkseagreen", "#8FBC8F");
        synonymToHexName.put("darkseagreen1", "#C1FFC1");
        synonymToHexName.put("darkseagreen2", "#B4EEB4");
        synonymToHexName.put("darkseagreen3", "#9BCD9B");
        synonymToHexName.put("darkseagreen4", "#698B69");
        synonymToHexName.put("darkslateblue", "#483D8B");
        synonymToHexName.put("darkslategray", "#2F4F4F");
        synonymToHexName.put("darkslategray1", "#97FFFF");
        synonymToHexName.put("darkslategray2", "#8DEEEE");
        synonymToHexName.put("darkslategray3", "#79CDCD");
        synonymToHexName.put("darkslategray4", "#528B8B");
        synonymToHexName.put("darkslategrey", "#2F4F4F");
        synonymToHexName.put("darkturquoise", "#00CED1");
        synonymToHexName.put("darkviolet", "#9400D3");
        synonymToHexName.put("deeppink", "#FF1493");
        synonymToHexName.put("deeppink1", "#FF1493");
        synonymToHexName.put("deeppink2", "#EE1289");
        synonymToHexName.put("deeppink3", "#CD1076");
        synonymToHexName.put("deeppink4", "#8B0A50");
        synonymToHexName.put("deepskyblue", "#00BFFF");
        synonymToHexName.put("deepskyblue1", "#00BFFF");
        synonymToHexName.put("deepskyblue2", "#00B2EE");
        synonymToHexName.put("deepskyblue3", "#009ACD");
        synonymToHexName.put("deepskyblue4", "#00688B");
        synonymToHexName.put("dimgray", "#696969");
        synonymToHexName.put("dimgrey", "#696969");
        synonymToHexName.put("dodgerblue", "#1E90FF");
        synonymToHexName.put("dodgerblue1", "#1E90FF");
        synonymToHexName.put("dodgerblue2", "#1C86EE");
        synonymToHexName.put("dodgerblue3", "#1874CD");
        synonymToHexName.put("dodgerblue4", "#104E8B");
        synonymToHexName.put("firebrick", "#B22222");
        synonymToHexName.put("firebrick1", "#FF3030");
        synonymToHexName.put("firebrick2", "#EE2C2C");
        synonymToHexName.put("firebrick3", "#CD2626");
        synonymToHexName.put("firebrick4", "#8B1A1A");
        synonymToHexName.put("floralwhite", "#FFFAF0");
        synonymToHexName.put("forestgreen", "#228B22");
        synonymToHexName.put("gainsboro", "#DCDCDC");
        synonymToHexName.put("ghostwhite", "#F8F8FF");
        synonymToHexName.put("gold", "#FFD700");
        synonymToHexName.put("gold1", "#FFD700");
        synonymToHexName.put("gold2", "#EEC900");
        synonymToHexName.put("gold3", "#CDAD00");
        synonymToHexName.put("gold4", "#8B7500");
        synonymToHexName.put("goldenrod", "#DAA520");
        synonymToHexName.put("goldenrod1", "#FFC125");
        synonymToHexName.put("goldenrod2", "#EEB422");
        synonymToHexName.put("goldenrod3", "#CD9B1D");
        synonymToHexName.put("goldenrod4", "#8B6914");
        synonymToHexName.put("gray", "#BEBEBE");
        synonymToHexName.put("gray0", "#000000");
        synonymToHexName.put("gray1", "#030303");
        synonymToHexName.put("gray2", "#050505");
        synonymToHexName.put("gray3", "#080808");
        synonymToHexName.put("gray4", "#0A0A0A");
        synonymToHexName.put("gray5", "#0D0D0D");
        synonymToHexName.put("gray6", "#0F0F0F");
        synonymToHexName.put("gray7", "#121212");
        synonymToHexName.put("gray8", "#141414");
        synonymToHexName.put("gray9", "#171717");
        synonymToHexName.put("gray10", "#1A1A1A");
        synonymToHexName.put("gray11", "#1C1C1C");
        synonymToHexName.put("gray12", "#1F1F1F");
        synonymToHexName.put("gray13", "#212121");
        synonymToHexName.put("gray14", "#242424");
        synonymToHexName.put("gray15", "#262626");
        synonymToHexName.put("gray16", "#292929");
        synonymToHexName.put("gray17", "#2B2B2B");
        synonymToHexName.put("gray18", "#2E2E2E");
        synonymToHexName.put("gray19", "#303030");
        synonymToHexName.put("gray20", "#333333");
        synonymToHexName.put("gray21", "#363636");
        synonymToHexName.put("gray22", "#383838");
        synonymToHexName.put("gray23", "#3B3B3B");
        synonymToHexName.put("gray24", "#3D3D3D");
        synonymToHexName.put("gray25", "#404040");
        synonymToHexName.put("gray26", "#424242");
        synonymToHexName.put("gray27", "#454545");
        synonymToHexName.put("gray28", "#474747");
        synonymToHexName.put("gray29", "#4A4A4A");
        synonymToHexName.put("gray30", "#4D4D4D");
        synonymToHexName.put("gray31", "#4F4F4F");
        synonymToHexName.put("gray32", "#525252");
        synonymToHexName.put("gray33", "#545454");
        synonymToHexName.put("gray34", "#575757");
        synonymToHexName.put("gray35", "#595959");
        synonymToHexName.put("gray36", "#5C5C5C");
        synonymToHexName.put("gray37", "#5E5E5E");
        synonymToHexName.put("gray38", "#616161");
        synonymToHexName.put("gray39", "#636363");
        synonymToHexName.put("gray40", "#666666");
        synonymToHexName.put("gray41", "#696969");
        synonymToHexName.put("gray42", "#6B6B6B");
        synonymToHexName.put("gray43", "#6E6E6E");
        synonymToHexName.put("gray44", "#707070");
        synonymToHexName.put("gray45", "#737373");
        synonymToHexName.put("gray46", "#757575");
        synonymToHexName.put("gray47", "#787878");
        synonymToHexName.put("gray48", "#7A7A7A");
        synonymToHexName.put("gray49", "#7D7D7D");
        synonymToHexName.put("gray50", "#7F7F7F");
        synonymToHexName.put("gray51", "#828282");
        synonymToHexName.put("gray52", "#858585");
        synonymToHexName.put("gray53", "#878787");
        synonymToHexName.put("gray54", "#8A8A8A");
        synonymToHexName.put("gray55", "#8C8C8C");
        synonymToHexName.put("gray56", "#8F8F8F");
        synonymToHexName.put("gray57", "#919191");
        synonymToHexName.put("gray58", "#949494");
        synonymToHexName.put("gray59", "#969696");
        synonymToHexName.put("gray60", "#999999");
        synonymToHexName.put("gray61", "#9C9C9C");
        synonymToHexName.put("gray62", "#9E9E9E");
        synonymToHexName.put("gray63", "#A1A1A1");
        synonymToHexName.put("gray64", "#A3A3A3");
        synonymToHexName.put("gray65", "#A6A6A6");
        synonymToHexName.put("gray66", "#A8A8A8");
        synonymToHexName.put("gray67", "#ABABAB");
        synonymToHexName.put("gray68", "#ADADAD");
        synonymToHexName.put("gray69", "#B0B0B0");
        synonymToHexName.put("gray70", "#B3B3B3");
        synonymToHexName.put("gray71", "#B5B5B5");
        synonymToHexName.put("gray72", "#B8B8B8");
        synonymToHexName.put("gray73", "#BABABA");
        synonymToHexName.put("gray74", "#BDBDBD");
        synonymToHexName.put("gray75", "#BFBFBF");
        synonymToHexName.put("gray76", "#C2C2C2");
        synonymToHexName.put("gray77", "#C4C4C4");
        synonymToHexName.put("gray78", "#C7C7C7");
        synonymToHexName.put("gray79", "#C9C9C9");
        synonymToHexName.put("gray80", "#CCCCCC");
        synonymToHexName.put("gray81", "#CFCFCF");
        synonymToHexName.put("gray82", "#D1D1D1");
        synonymToHexName.put("gray83", "#D4D4D4");
        synonymToHexName.put("gray84", "#D6D6D6");
        synonymToHexName.put("gray85", "#D9D9D9");
        synonymToHexName.put("gray86", "#DBDBDB");
        synonymToHexName.put("gray87", "#DEDEDE");
        synonymToHexName.put("gray88", "#E0E0E0");
        synonymToHexName.put("gray89", "#E3E3E3");
        synonymToHexName.put("gray90", "#E5E5E5");
        synonymToHexName.put("gray91", "#E8E8E8");
        synonymToHexName.put("gray92", "#EBEBEB");
        synonymToHexName.put("gray93", "#EDEDED");
        synonymToHexName.put("gray94", "#F0F0F0");
        synonymToHexName.put("gray95", "#F2F2F2");
        synonymToHexName.put("gray96", "#F5F5F5");
        synonymToHexName.put("gray97", "#F7F7F7");
        synonymToHexName.put("gray98", "#FAFAFA");
        synonymToHexName.put("gray99", "#FCFCFC");
        synonymToHexName.put("gray100", "#FFFFFF");
        synonymToHexName.put("green", "#00FF00");
        synonymToHexName.put("green1", "#00FF00");
        synonymToHexName.put("green2", "#00EE00");
        synonymToHexName.put("green3", "#00CD00");
        synonymToHexName.put("green4", "#008B00");
        synonymToHexName.put("greenyellow", "#ADFF2F");
        synonymToHexName.put("grey", "#BEBEBE");
        synonymToHexName.put("grey0", "#000000");
        synonymToHexName.put("grey1", "#030303");
        synonymToHexName.put("grey2", "#050505");
        synonymToHexName.put("grey3", "#080808");
        synonymToHexName.put("grey4", "#0A0A0A");
        synonymToHexName.put("grey5", "#0D0D0D");
        synonymToHexName.put("grey6", "#0F0F0F");
        synonymToHexName.put("grey7", "#121212");
        synonymToHexName.put("grey8", "#141414");
        synonymToHexName.put("grey9", "#171717");
        synonymToHexName.put("grey10", "#1A1A1A");
        synonymToHexName.put("grey11", "#1C1C1C");
        synonymToHexName.put("grey12", "#1F1F1F");
        synonymToHexName.put("grey13", "#212121");
        synonymToHexName.put("grey14", "#242424");
        synonymToHexName.put("grey15", "#262626");
        synonymToHexName.put("grey16", "#292929");
        synonymToHexName.put("grey17", "#2B2B2B");
        synonymToHexName.put("grey18", "#2E2E2E");
        synonymToHexName.put("grey19", "#303030");
        synonymToHexName.put("grey20", "#333333");
        synonymToHexName.put("grey21", "#363636");
        synonymToHexName.put("grey22", "#383838");
        synonymToHexName.put("grey23", "#3B3B3B");
        synonymToHexName.put("grey24", "#3D3D3D");
        synonymToHexName.put("grey25", "#404040");
        synonymToHexName.put("grey26", "#424242");
        synonymToHexName.put("grey27", "#454545");
        synonymToHexName.put("grey28", "#474747");
        synonymToHexName.put("grey29", "#4A4A4A");
        synonymToHexName.put("grey30", "#4D4D4D");
        synonymToHexName.put("grey31", "#4F4F4F");
        synonymToHexName.put("grey32", "#525252");
        synonymToHexName.put("grey33", "#545454");
        synonymToHexName.put("grey34", "#575757");
        synonymToHexName.put("grey35", "#595959");
        synonymToHexName.put("grey36", "#5C5C5C");
        synonymToHexName.put("grey37", "#5E5E5E");
        synonymToHexName.put("grey38", "#616161");
        synonymToHexName.put("grey39", "#636363");
        synonymToHexName.put("grey40", "#666666");
        synonymToHexName.put("grey41", "#696969");
        synonymToHexName.put("grey42", "#6B6B6B");
        synonymToHexName.put("grey43", "#6E6E6E");
        synonymToHexName.put("grey44", "#707070");
        synonymToHexName.put("grey45", "#737373");
        synonymToHexName.put("grey46", "#757575");
        synonymToHexName.put("grey47", "#787878");
        synonymToHexName.put("grey48", "#7A7A7A");
        synonymToHexName.put("grey49", "#7D7D7D");
        synonymToHexName.put("grey50", "#7F7F7F");
        synonymToHexName.put("grey51", "#828282");
        synonymToHexName.put("grey52", "#858585");
        synonymToHexName.put("grey53", "#878787");
        synonymToHexName.put("grey54", "#8A8A8A");
        synonymToHexName.put("grey55", "#8C8C8C");
        synonymToHexName.put("grey56", "#8F8F8F");
        synonymToHexName.put("grey57", "#919191");
        synonymToHexName.put("grey58", "#949494");
        synonymToHexName.put("grey59", "#969696");
        synonymToHexName.put("grey60", "#999999");
        synonymToHexName.put("grey61", "#9C9C9C");
        synonymToHexName.put("grey62", "#9E9E9E");
        synonymToHexName.put("grey63", "#A1A1A1");
        synonymToHexName.put("grey64", "#A3A3A3");
        synonymToHexName.put("grey65", "#A6A6A6");
        synonymToHexName.put("grey66", "#A8A8A8");
        synonymToHexName.put("grey67", "#ABABAB");
        synonymToHexName.put("grey68", "#ADADAD");
        synonymToHexName.put("grey69", "#B0B0B0");
        synonymToHexName.put("grey70", "#B3B3B3");
        synonymToHexName.put("grey71", "#B5B5B5");
        synonymToHexName.put("grey72", "#B8B8B8");
        synonymToHexName.put("grey73", "#BABABA");
        synonymToHexName.put("grey74", "#BDBDBD");
        synonymToHexName.put("grey75", "#BFBFBF");
        synonymToHexName.put("grey76", "#C2C2C2");
        synonymToHexName.put("grey77", "#C4C4C4");
        synonymToHexName.put("grey78", "#C7C7C7");
        synonymToHexName.put("grey79", "#C9C9C9");
        synonymToHexName.put("grey80", "#CCCCCC");
        synonymToHexName.put("grey81", "#CFCFCF");
        synonymToHexName.put("grey82", "#D1D1D1");
        synonymToHexName.put("grey83", "#D4D4D4");
        synonymToHexName.put("grey84", "#D6D6D6");
        synonymToHexName.put("grey85", "#D9D9D9");
        synonymToHexName.put("grey86", "#DBDBDB");
        synonymToHexName.put("grey87", "#DEDEDE");
        synonymToHexName.put("grey88", "#E0E0E0");
        synonymToHexName.put("grey89", "#E3E3E3");
        synonymToHexName.put("grey90", "#E5E5E5");
        synonymToHexName.put("grey91", "#E8E8E8");
        synonymToHexName.put("grey92", "#EBEBEB");
        synonymToHexName.put("grey93", "#EDEDED");
        synonymToHexName.put("grey94", "#F0F0F0");
        synonymToHexName.put("grey95", "#F2F2F2");
        synonymToHexName.put("grey96", "#F5F5F5");
        synonymToHexName.put("grey97", "#F7F7F7");
        synonymToHexName.put("grey98", "#FAFAFA");
        synonymToHexName.put("grey99", "#FCFCFC");
        synonymToHexName.put("grey100", "#FFFFFF");
        synonymToHexName.put("honeydew", "#F0FFF0");
        synonymToHexName.put("honeydew1", "#F0FFF0");
        synonymToHexName.put("honeydew2", "#E0EEE0");
        synonymToHexName.put("honeydew3", "#C1CDC1");
        synonymToHexName.put("honeydew4", "#838B83");
        synonymToHexName.put("hotpink", "#FF69B4");
        synonymToHexName.put("hotpink1", "#FF6EB4");
        synonymToHexName.put("hotpink2", "#EE6AA7");
        synonymToHexName.put("hotpink3", "#CD6090");
        synonymToHexName.put("hotpink4", "#8B3A62");
        synonymToHexName.put("indianred", "#CD5C5C");
        synonymToHexName.put("indianred1", "#FF6A6A");
        synonymToHexName.put("indianred2", "#EE6363");
        synonymToHexName.put("indianred3", "#CD5555");
        synonymToHexName.put("indianred4", "#8B3A3A");
        synonymToHexName.put("ivory", "#FFFFF0");
        synonymToHexName.put("ivory1", "#FFFFF0");
        synonymToHexName.put("ivory2", "#EEEEE0");
        synonymToHexName.put("ivory3", "#CDCDC1");
        synonymToHexName.put("ivory4", "#8B8B83");
        synonymToHexName.put("khaki", "#F0E68C");
        synonymToHexName.put("khaki1", "#FFF68F");
        synonymToHexName.put("khaki2", "#EEE685");
        synonymToHexName.put("khaki3", "#CDC673");
        synonymToHexName.put("khaki4", "#8B864E");
        synonymToHexName.put("lavender", "#E6E6FA");
        synonymToHexName.put("lavenderblush", "#FFF0F5");
        synonymToHexName.put("lavenderblush1", "#FFF0F5");
        synonymToHexName.put("lavenderblush2", "#EEE0E5");
        synonymToHexName.put("lavenderblush3", "#CDC1C5");
        synonymToHexName.put("lavenderblush4", "#8B8386");
        synonymToHexName.put("lawngreen", "#7CFC00");
        synonymToHexName.put("lemonchiffon", "#FFFACD");
        synonymToHexName.put("lemonchiffon1", "#FFFACD");
        synonymToHexName.put("lemonchiffon2", "#EEE9BF");
        synonymToHexName.put("lemonchiffon3", "#CDC9A5");
        synonymToHexName.put("lemonchiffon4", "#8B8970");
        synonymToHexName.put("lightblue", "#ADD8E6");
        synonymToHexName.put("lightblue1", "#BFEFFF");
        synonymToHexName.put("lightblue2", "#B2DFEE");
        synonymToHexName.put("lightblue3", "#9AC0CD");
        synonymToHexName.put("lightblue4", "#68838B");
        synonymToHexName.put("lightcoral", "#F08080");
        synonymToHexName.put("lightcyan", "#E0FFFF");
        synonymToHexName.put("lightcyan1", "#E0FFFF");
        synonymToHexName.put("lightcyan2", "#D1EEEE");
        synonymToHexName.put("lightcyan3", "#B4CDCD");
        synonymToHexName.put("lightcyan4", "#7A8B8B");
        synonymToHexName.put("lightgoldenrod", "#EEDD82");
        synonymToHexName.put("lightgoldenrod1", "#FFEC8B");
        synonymToHexName.put("lightgoldenrod2", "#EEDC82");
        synonymToHexName.put("lightgoldenrod3", "#CDBE70");
        synonymToHexName.put("lightgoldenrod4", "#8B814C");
        synonymToHexName.put("lightgoldenrodyellow", "#FAFAD2");
        synonymToHexName.put("lightgray", "#D3D3D3");
        synonymToHexName.put("lightgreen", "#90EE90");
        synonymToHexName.put("lightgrey", "#D3D3D3");
        synonymToHexName.put("lightpink", "#FFB6C1");
        synonymToHexName.put("lightpink1", "#FFAEB9");
        synonymToHexName.put("lightpink2", "#EEA2AD");
        synonymToHexName.put("lightpink3", "#CD8C95");
        synonymToHexName.put("lightpink4", "#8B5F65");
        synonymToHexName.put("lightsalmon", "#FFA07A");
        synonymToHexName.put("lightsalmon1", "#FFA07A");
        synonymToHexName.put("lightsalmon2", "#EE9572");
        synonymToHexName.put("lightsalmon3", "#CD8162");
        synonymToHexName.put("lightsalmon4", "#8B5742");
        synonymToHexName.put("lightseagreen", "#20B2AA");
        synonymToHexName.put("lightskyblue", "#87CEFA");
        synonymToHexName.put("lightskyblue1", "#B0E2FF");
        synonymToHexName.put("lightskyblue2", "#A4D3EE");
        synonymToHexName.put("lightskyblue3", "#8DB6CD");
        synonymToHexName.put("lightskyblue4", "#607B8B");
        synonymToHexName.put("lightslateblue", "#8470FF");
        synonymToHexName.put("lightslategray", "#778899");
        synonymToHexName.put("lightslategrey", "#778899");
        synonymToHexName.put("lightsteelblue", "#B0C4DE");
        synonymToHexName.put("lightsteelblue1", "#CAE1FF");
        synonymToHexName.put("lightsteelblue2", "#BCD2EE");
        synonymToHexName.put("lightsteelblue3", "#A2B5CD");
        synonymToHexName.put("lightsteelblue4", "#6E7B8B");
        synonymToHexName.put("lightyellow", "#FFFFE0");
        synonymToHexName.put("lightyellow1", "#FFFFE0");
        synonymToHexName.put("lightyellow2", "#EEEED1");
        synonymToHexName.put("lightyellow3", "#CDCDB4");
        synonymToHexName.put("lightyellow4", "#8B8B7A");
        synonymToHexName.put("limegreen", "#32CD32");
        synonymToHexName.put("linen", "#FAF0E6");
        synonymToHexName.put("magenta", "#FF00FF");
        synonymToHexName.put("magenta1", "#FF00FF");
        synonymToHexName.put("magenta2", "#EE00EE");
        synonymToHexName.put("magenta3", "#CD00CD");
        synonymToHexName.put("magenta4", "#8B008B");
        synonymToHexName.put("maroon", "#B03060");
        synonymToHexName.put("maroon1", "#FF34B3");
        synonymToHexName.put("maroon2", "#EE30A7");
        synonymToHexName.put("maroon3", "#CD2990");
        synonymToHexName.put("maroon4", "#8B1C62");
        synonymToHexName.put("mediumaquamarine", "#66CDAA");
        synonymToHexName.put("mediumblue", "#0000CD");
        synonymToHexName.put("mediumorchid", "#BA55D3");
        synonymToHexName.put("mediumorchid1", "#E066FF");
        synonymToHexName.put("mediumorchid2", "#D15FEE");
        synonymToHexName.put("mediumorchid3", "#B452CD");
        synonymToHexName.put("mediumorchid4", "#7A378B");
        synonymToHexName.put("mediumpurple", "#9370DB");
        synonymToHexName.put("mediumpurple1", "#AB82FF");
        synonymToHexName.put("mediumpurple2", "#9F79EE");
        synonymToHexName.put("mediumpurple3", "#8968CD");
        synonymToHexName.put("mediumpurple4", "#5D478B");
        synonymToHexName.put("mediumseagreen", "#3CB371");
        synonymToHexName.put("mediumslateblue", "#7B68EE");
        synonymToHexName.put("mediumspringgreen", "#00FA9A");
        synonymToHexName.put("mediumturquoise", "#48D1CC");
        synonymToHexName.put("mediumvioletred", "#C71585");
        synonymToHexName.put("midnightblue", "#191970");
        synonymToHexName.put("mintcream", "#F5FFFA");
        synonymToHexName.put("mistyrose", "#FFE4E1");
        synonymToHexName.put("mistyrose1", "#FFE4E1");
        synonymToHexName.put("mistyrose2", "#EED5D2");
        synonymToHexName.put("mistyrose3", "#CDB7B5");
        synonymToHexName.put("mistyrose4", "#8B7D7B");
        synonymToHexName.put("moccasin", "#FFE4B5");
        synonymToHexName.put("navajowhite", "#FFDEAD");
        synonymToHexName.put("navajowhite1", "#FFDEAD");
        synonymToHexName.put("navajowhite2", "#EECFA1");
        synonymToHexName.put("navajowhite3", "#CDB38B");
        synonymToHexName.put("navajowhite4", "#8B795E");
        synonymToHexName.put("navy", "#000080");
        synonymToHexName.put("navyblue", "#000080");
        synonymToHexName.put("oldlace", "#FDF5E6");
        synonymToHexName.put("olivedrab", "#6B8E23");
        synonymToHexName.put("olivedrab1", "#C0FF3E");
        synonymToHexName.put("olivedrab2", "#B3EE3A");
        synonymToHexName.put("olivedrab3", "#9ACD32");
        synonymToHexName.put("olivedrab4", "#698B22");
        synonymToHexName.put("orange", "#FFA500");
        synonymToHexName.put("orange1", "#FFA500");
        synonymToHexName.put("orange2", "#EE9A00");
        synonymToHexName.put("orange3", "#CD8500");
        synonymToHexName.put("orange4", "#8B5A00");
        synonymToHexName.put("orangered", "#FF4500");
        synonymToHexName.put("orangered1", "#FF4500");
        synonymToHexName.put("orangered2", "#EE4000");
        synonymToHexName.put("orangered3", "#CD3700");
        synonymToHexName.put("orangered4", "#8B2500");
        synonymToHexName.put("orchid", "#DA70D6");
        synonymToHexName.put("orchid1", "#FF83FA");
        synonymToHexName.put("orchid2", "#EE7AE9");
        synonymToHexName.put("orchid3", "#CD69C9");
        synonymToHexName.put("orchid4", "#8B4789");
        synonymToHexName.put("palegoldenrod", "#EEE8AA");
        synonymToHexName.put("palegreen", "#98FB98");
        synonymToHexName.put("palegreen1", "#9AFF9A");
        synonymToHexName.put("palegreen2", "#90EE90");
        synonymToHexName.put("palegreen3", "#7CCD7C");
        synonymToHexName.put("palegreen4", "#548B54");
        synonymToHexName.put("paleturquoise", "#AFEEEE");
        synonymToHexName.put("paleturquoise1", "#BBFFFF");
        synonymToHexName.put("paleturquoise2", "#AEEEEE");
        synonymToHexName.put("paleturquoise3", "#96CDCD");
        synonymToHexName.put("paleturquoise4", "#668B8B");
        synonymToHexName.put("palevioletred", "#DB7093");
        synonymToHexName.put("palevioletred1", "#FF82AB");
        synonymToHexName.put("palevioletred2", "#EE799F");
        synonymToHexName.put("palevioletred3", "#CD6889");
        synonymToHexName.put("palevioletred4", "#8B475D");
        synonymToHexName.put("papayawhip", "#FFEFD5");
        synonymToHexName.put("peachpuff", "#FFDAB9");
        synonymToHexName.put("peachpuff1", "#FFDAB9");
        synonymToHexName.put("peachpuff2", "#EECBAD");
        synonymToHexName.put("peachpuff3", "#CDAF95");
        synonymToHexName.put("peachpuff4", "#8B7765");
        synonymToHexName.put("peru", "#CD853F");
        synonymToHexName.put("pink", "#FFC0CB");
        synonymToHexName.put("pink1", "#FFB5C5");
        synonymToHexName.put("pink2", "#EEA9B8");
        synonymToHexName.put("pink3", "#CD919E");
        synonymToHexName.put("pink4", "#8B636C");
        synonymToHexName.put("plum", "#DDA0DD");
        synonymToHexName.put("plum1", "#FFBBFF");
        synonymToHexName.put("plum2", "#EEAEEE");
        synonymToHexName.put("plum3", "#CD96CD");
        synonymToHexName.put("plum4", "#8B668B");
        synonymToHexName.put("powderblue", "#B0E0E6");
        synonymToHexName.put("purple", "#A020F0");
        synonymToHexName.put("purple1", "#9B30FF");
        synonymToHexName.put("purple2", "#912CEE");
        synonymToHexName.put("purple3", "#7D26CD");
        synonymToHexName.put("purple4", "#551A8B");
        synonymToHexName.put("red", "#FF0000");
        synonymToHexName.put("red1", "#FF0000");
        synonymToHexName.put("red2", "#EE0000");
        synonymToHexName.put("red3", "#CD0000");
        synonymToHexName.put("red4", "#8B0000");
        synonymToHexName.put("rosybrown", "#BC8F8F");
        synonymToHexName.put("rosybrown1", "#FFC1C1");
        synonymToHexName.put("rosybrown2", "#EEB4B4");
        synonymToHexName.put("rosybrown3", "#CD9B9B");
        synonymToHexName.put("rosybrown4", "#8B6969");
        synonymToHexName.put("royalblue", "#4169E1");
        synonymToHexName.put("royalblue1", "#4876FF");
        synonymToHexName.put("royalblue2", "#436EEE");
        synonymToHexName.put("royalblue3", "#3A5FCD");
        synonymToHexName.put("royalblue4", "#27408B");
        synonymToHexName.put("snewData.addlebrown", "#8B4513");
        synonymToHexName.put("salmon", "#FA8072");
        synonymToHexName.put("salmon1", "#FF8C69");
        synonymToHexName.put("salmon2", "#EE8262");
        synonymToHexName.put("salmon3", "#CD7054");
        synonymToHexName.put("salmon4", "#8B4C39");
        synonymToHexName.put("sandybrown", "#F4A460");
        synonymToHexName.put("seagreen", "#2E8B57");
        synonymToHexName.put("seagreen1", "#54FF9F");
        synonymToHexName.put("seagreen2", "#4EEE94");
        synonymToHexName.put("seagreen3", "#43CD80");
        synonymToHexName.put("seagreen4", "#2E8B57");
        synonymToHexName.put("seashell", "#FFF5EE");
        synonymToHexName.put("seashell1", "#FFF5EE");
        synonymToHexName.put("seashell2", "#EEE5DE");
        synonymToHexName.put("seashell3", "#CDC5BF");
        synonymToHexName.put("seashell4", "#8B8682");
        synonymToHexName.put("sienna", "#A0522D");
        synonymToHexName.put("sienna1", "#FF8247");
        synonymToHexName.put("sienna2", "#EE7942");
        synonymToHexName.put("sienna3", "#CD6839");
        synonymToHexName.put("sienna4", "#8B4726");
        synonymToHexName.put("skyblue", "#87CEEB");
        synonymToHexName.put("skyblue1", "#87CEFF");
        synonymToHexName.put("skyblue2", "#7EC0EE");
        synonymToHexName.put("skyblue3", "#6CA6CD");
        synonymToHexName.put("skyblue4", "#4A708B");
        synonymToHexName.put("slateblue", "#6A5ACD");
        synonymToHexName.put("slateblue1", "#836FFF");
        synonymToHexName.put("slateblue2", "#7A67EE");
        synonymToHexName.put("slateblue3", "#6959CD");
        synonymToHexName.put("slateblue4", "#473C8B");
        synonymToHexName.put("slategray", "#708090");
        synonymToHexName.put("slategray1", "#C6E2FF");
        synonymToHexName.put("slategray2", "#B9D3EE");
        synonymToHexName.put("slategray3", "#9FB6CD");
        synonymToHexName.put("slategray4", "#6C7B8B");
        synonymToHexName.put("slategrey", "#708090");
        synonymToHexName.put("snow", "#FFFAFA");
        synonymToHexName.put("snow1", "#FFFAFA");
        synonymToHexName.put("snow2", "#EEE9E9");
        synonymToHexName.put("snow3", "#CDC9C9");
        synonymToHexName.put("snow4", "#8B8989");
        synonymToHexName.put("springgreen", "#00FF7F");
        synonymToHexName.put("springgreen1", "#00FF7F");
        synonymToHexName.put("springgreen2", "#00EE76");
        synonymToHexName.put("springgreen3", "#00CD66");
        synonymToHexName.put("springgreen4", "#008B45");
        synonymToHexName.put("steelblue", "#4682B4");
        synonymToHexName.put("steelblue1", "#63B8FF");
        synonymToHexName.put("steelblue2", "#5CACEE");
        synonymToHexName.put("steelblue3", "#4F94CD");
        synonymToHexName.put("steelblue4", "#36648B");
        synonymToHexName.put("tan", "#D2B48C");
        synonymToHexName.put("tan1", "#FFA54F");
        synonymToHexName.put("tan2", "#EE9A49");
        synonymToHexName.put("tan3", "#CD853F");
        synonymToHexName.put("tan4", "#8B5A2B");
        synonymToHexName.put("thistle", "#D8BFD8");
        synonymToHexName.put("thistle1", "#FFE1FF");
        synonymToHexName.put("thistle2", "#EED2EE");
        synonymToHexName.put("thistle3", "#CDB5CD");
        synonymToHexName.put("thistle4", "#8B7B8B");
        synonymToHexName.put("tomato", "#FF6347");
        synonymToHexName.put("tomato1", "#FF6347");
        synonymToHexName.put("tomato2", "#EE5C42");
        synonymToHexName.put("tomato3", "#CD4F39");
        synonymToHexName.put("tomato4", "#8B3626");
        synonymToHexName.put("turquoise", "#40E0D0");
        synonymToHexName.put("turquoise1", "#00F5FF");
        synonymToHexName.put("turquoise2", "#00E5EE");
        synonymToHexName.put("turquoise3", "#00C5CD");
        synonymToHexName.put("turquoise4", "#00868B");
        synonymToHexName.put("violet", "#EE82EE");
        synonymToHexName.put("violetred", "#D02090");
        synonymToHexName.put("violetred1", "#FF3E96");
        synonymToHexName.put("violetred2", "#EE3A8C");
        synonymToHexName.put("violetred3", "#CD3278");
        synonymToHexName.put("violetred4", "#8B2252");
        synonymToHexName.put("wheat", "#F5DEB3");
        synonymToHexName.put("wheat1", "#FFE7BA");
        synonymToHexName.put("wheat2", "#EED8AE");
        synonymToHexName.put("wheat3", "#CDBA96");
        synonymToHexName.put("wheat4", "#8B7E66");
        synonymToHexName.put("whitesmoke", "#F5F5F5");
        synonymToHexName.put("yellow", "#FFFF00");
        synonymToHexName.put("yellow1", "#FFFF00");
        synonymToHexName.put("yellow2", "#EEEE00");
        synonymToHexName.put("yellow3", "#CDCD00");
        synonymToHexName.put("yellow4", "#8B8B00");
        synonymToHexName.put("yellowgreen", "#9ACD32");
    }
}
